@@ -15,6 +15,7 @@ from spider.vehicle_model import Bicycle
 def generate_corridor_bboxes(initial_guess:np.ndarray, bboxes:TrackingBoxList,
                              x_bound=None, y_bound=None,
                              delta=0.1, max_expand=50.0,
+                             use_frenet=False
                              ):
     '''
     # todo: 没加上障碍物膨胀的功能，应该先根据自车搞一些近似的disks出来（嫌麻烦就设定1个圆盘），然后根据圆盘半径来设定膨胀的半径
@@ -37,8 +38,10 @@ def generate_corridor_bboxes(initial_guess:np.ndarray, bboxes:TrackingBoxList,
 
         # if t == 0:
         #     continue
-
-        collision_checker.setObstacles(bboxes_vertices=bboxes.getBoxVertices(step=i))
+        if use_frenet:
+            collision_checker.set_obstacles(bboxes_vertices=bboxes.get_frenet_vertices_at(step=i))
+        else:
+            collision_checker.set_obstacles(bboxes_vertices=bboxes.get_vertices_at(step=i))
 
         seed = np.float64([x-0.01, y-0.01, x+0.01, y+0.01])  # 坍缩为一个小区域,四个方向发散以扩展
         sign = [-1, -1, 1, 1]
@@ -54,7 +57,7 @@ def generate_corridor_bboxes(initial_guess:np.ndarray, bboxes:TrackingBoxList,
                 temp_space = space.copy()
                 temp_space[j] += sign[j] * delta
 
-                collision_checker.setEgoVehicleBox(AABB_vertices(temp_space))
+                collision_checker.set_ego_box(AABB_vertices(temp_space))
 
                 if np.abs(temp_space[j] - seed[j]) > max_expand or collision_checker.check() or \
                         (road_bound[j]-temp_space[j])*sign[j]<0:
@@ -112,7 +115,7 @@ def getConsMat(s0,s_d0,s_dd0,l0,l_d0,l_dd0, target_l_bound,
     # veh_model = Bicycle(s0,l0, s_d0, s_dd0,heading=0., dt=dt, wheelbase=wheelbase)
     # traj.derivative(veh_model,xs=ss,ys=ls)
     # bboxes.predict(traj.t) # 放到外面去了
-    corridors = generate_corridor_bboxes(initial_guess, bboxes,x_bound=(-1,80), y_bound=l_bound)
+    corridors = generate_corridor_bboxes(initial_guess, bboxes,x_bound=(-1,80), y_bound=l_bound, use_frenet=True)
     #:return: corridor: [ [x1_min, y1_min, x1_max, y1_max],... ]
     slb,llb, sub,lub = corridors.T#[:,0],corridors[:,1],corridors[:,2],corridors[:,3]
     Aineq_list += [p.Ms,-p.Ms,p.Ml,-p.Ml]
@@ -242,7 +245,8 @@ class FrenetTrajectoryOptimizer(BaseOptimizer):
         # todo: 输入sl_pair_array & 初始横纵向状态
         pass
 
-    def get_corridors(self):
+    @property
+    def corridors(self):
         return self._corridors
 
 
@@ -250,6 +254,7 @@ class FrenetTrajectoryOptimizer(BaseOptimizer):
 if __name__ == '__main__':
     from spider.elements import TrackingBox
     from spider.visualize import draw_polygon
+    from spider.utils.transform.frenet import FrenetCoordinateTransformer
     import matplotlib.pyplot as plt
 
 
@@ -265,6 +270,12 @@ if __name__ == '__main__':
     veh_width = 2
     wheelbase = 3.0
 
+    xs = np.linspace(0, 80, 80)
+    ys = np.linspace(0, 0, 80)
+    centerline = np.column_stack((xs, ys))
+    transformer = FrenetCoordinateTransformer(centerline)
+
+
     # observation
     bboxes = TrackingBoxList()
     obs = [
@@ -278,6 +289,7 @@ if __name__ == '__main__':
         tb = TrackingBox.from_vertices(vertices=vertices, vx=vx, vy=vy)
         bboxes.append(tb)
     bboxes.predict([dt * i for i in range(steps)])
+    # bboxes = transformer.cart2frenet4boxes(bboxes, convert_prediction=True)
 
     s0, s_d0, s_dd0 = 0., 30 / 3.6, 0.
     l0, l_d0, l_dd0 = 0., 0., 0.
@@ -295,7 +307,7 @@ if __name__ == '__main__':
     initial_frenet_trajectory.l_2dot.append(l_dd0)
 
     optim_traj = optim.optimize_traj(initial_frenet_trajectory, bboxes, offset_bound=(-3.5*0.5, 3.5*1.5))
-    corridors = optim.get_corridors()
+    corridors = optim.corridors
 
     for x, y, vx, vy in obs:
         vertices = AABB_vertices([x - veh_length / 2, y - veh_width / 2, x + veh_length / 2, y + veh_width / 2])
